@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20241031';
+our $VERSION = '0.20241129';
 
-# Table last modified: 2024-10-31
+# Table last modified: 2024-11-29
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[0-2]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
@@ -29,7 +29,7 @@ our %ZIP_TABLE = (
     '022' => '(?:8(?:5(?:12|0[1-578])|602))',
     '023' => '(?:(?:049[23]|1192|8501))',
     '024' => '(?:(?:85(?:20|55|0[15-7]|1[0138])|0(?:19[2-5]|392)))',
-    '025' => '(?:(?:8(?:60[12]|501)|039[235]))',
+    '025' => '(?:(?:8(?:60[12]|501)|039[2-5]))',
     '026' => '(?:8(?:5(?:50|67)|686))',
     '027' => '(?:(?:850[1-3]|0595))',
     '028' => '(?:(?:8(?:0(?:4[02]|3[01])|392|696)|7(?:39[2-7]|[15]92|995)|4(?:39[358]|19[35])|(?:0[135]|1[13])92|6(?:19[23568]|892)|3(?:69[2457]|392)|5495))',
@@ -63,7 +63,7 @@ our %ZIP_TABLE = (
     '057' => '(?:85(?:11|58))',
     '058' => '(?:(?:0292|8501))',
     '059' => '(?:(?:1(?:39[2-6]|59[2-6]|69[23]|292)|0(?:59[2568]|99[3578]|49[236])|2(?:[14]92|598)|8[67]01|3195))',
-    '060' => '(?:8(?:5(?:[38]\d|4[1-9]|[12][0-35-9]|6[0135-9]|7[02-9]|0[1-68]|5[0-46-9])|6(?:1\d|5[14-68]|8[6-8]|7[016-8]|0[1-9]|6[16-8]|2[1-57-9]|4[0-46-9]|3[0-24-9])|7(?:11|67|9[5-7]|7[46]|0[35-7]|2[15])|406))',
+    '060' => '(?:8(?:5(?:[38]\d|4[1-9]|[12][0-35-9]|6[0135-9]|7[02-9]|0[1-68]|5[0-46-9])|6(?:1\d|5[14-68]|8[6-8]|7[016-8]|0[1-9]|6[16-8]|2[1-57-9]|4[0-46-9]|3[0-24-9])|7(?:11|67|9[5-7]|7[146]|0[35-7]|2[15])|406))',
     '061' => '(?:(?:1(?:39[2-6]|49[236-8]|19[256])|0(?:29[2356]|59[25]|692)|3(?:29[2-6]|197|692)|2292|8501))',
     '062' => '(?:8(?:6(?:86|1[278]|0[1-357-9]|3[0135]|2[24]|4[12]|6[68])|5(?:01|20|7[025]|1[013467]|5[58]|3[029])))',
     '063' => '(?:8(?:5(?:22|0[17]|5[58]|[18][05])|6(?:0[1-36-8]|1[12]|4[15])))',
@@ -103,7 +103,7 @@ our %ZIP_TABLE = (
     '097' => '(?:8(?:5(?:10|85|5[58]|2[57])|6(?:[03]9|[68]6|78)))',
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
-    '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|6[0-57-9]|0[1-579]|5[0-35689]|7[013-9])|1(?:7[2468]|1[0137-9]|8[124-9]|2[013-8]|0[1-57-9]|6[05689]|4[0-24]|5[0-24589]|3[0-69])|2(?:28|51|70|0[1357]|8[23578]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|3[2358]|2[1245]|0[2367]|4[15]|1[01]|8[038])|5(?:11|33|4[03]|5[058]|6[07]|8[58]|7[57]|2[0-2]|0[235-7])|6(?:55|2[019]|3[19]|6[356]|7[67]|1[07]|0[126]|4[049])|4(?:5[06]|1[015]|3[09]|0[235]|2[147]|[48][48])|0(?:19|5[015]|7[07-9]|8[068]|6[56])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
+    '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|6[0-57-9]|0[1-579]|5[0-35689]|7[013-9])|1(?:7[2468]|1[0137-9]|8[124-9]|2[013-8]|0[1-57-9]|6[05689]|4[0-24]|5[0-24589]|3[0-69])|2(?:28|51|70|0[1357]|8[23578]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|3[2358]|2[1245]|0[2367]|4[15]|1[01]|8[038])|5(?:11|33|4[03]|5[058]|6[07]|8[58]|7[57]|2[0-2]|0[235-7])|6(?:55|2[019]|3[19]|6[356]|7[67]|1[07]|0[126]|4[049])|4(?:5[06]|1[015]|2[47]|3[09]|0[235]|[48][48])|0(?:19|5[015]|7[07-9]|8[068]|6[56])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
     '101' => '(?:8(?:4(?:1[0568]|6[0-246]|7[057]|4[13-68]|3[0379]|8[05]|0[58]|5[0169]|2[1-59])|6(?:8[28]|0[356]|5[146]|6[57]|2[1246-9]|3[01367]|7[026]|4[235-8]|1[01679])|5(?:3[0-245]|6[1258]|7[59]|4[28]|1[25]|0[249]|8[0569]|2[0-578]|5[24589])|3(?:5[013589]|8[38]|4[367]|0[17-9]|3[3568]|1[0138]|2[3-69]|7[258]|6[267])|7(?:0[137]|1[0-25-8])|9(?:41|50|7[37]|8[36])|2(?:28|0[14]|1[0359])|0(?:11|5[04]|0[128])|1(?:01|89)))',
     '102' => '(?:8(?:1(?:1[0-357-9]|2[02-58]|8[124-8]|5[0-25]|3[0-289]|0[1-39]|7[0-25-8]|9[0-5]|4[0-24]|6[016])|5(?:0[2-468]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|1[0-3569]|6[013-79]|8[023568])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|4[0158]|2[0146]|8[489]|3[037]|1[01479])|2(?:5[015]|3[0-24-68]|6[045]|8[28]|7[2-57]|2[1-68]|[01][15]|4[016])|3(?:7[0-37]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|4[139]|5[0367]|0[1359])|0(?:30|77|8[0-358]|2[256]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
     '103' => '(?:8(?:2(?:5[0-2569]|3[0-689]|7[036-8]|0[1-68]|8[2457]|1[0-248]|6[0156]|2[124589]|4[013578])|4(?:7[0-3]|0[1-57]|6[0-24-68]|4[38]|3[0-589]|1[0-79]|2[24-7]|8[02457-9]|5[016])|3(?:70|0[1378]|8[0348]|4[15-7]|1[1-478]|5[0-248]|6[036]|3[01357-9]|2[13-58])|5(?:1[0-257]|5[12468]|7[17]|2[0-25]|0[1-356]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|3[169]|7[67]|6[068]|8[0469])|0[01]1))',
@@ -127,7 +127,7 @@ our %ZIP_TABLE = (
     '125' => '(?:8(?:5(?:0[3-8]|8[58]|1[1-47]|2[026])|601))',
     '130' => '(?:8(?:5(?:8[03-58]|2[0-258]|7[057]|3[013-589]|5[3-8]|4[3568]|6[135-7]|0[13-9]|1[0-8])|6(?:71|86|4[02]|3[367]|5[05]|2[58]|6[068]|1[125]|0[1-689])|7(?:[12]0|0[16])))',
     '131' => '(?:8(?:5(?:65|1[0-389]|3[03]|2[0467]|5[058]|8[458]|0[1357-9])|139|634|711))',
-    '132' => '(?:8(?:5(?:[18]5|33|5[015]|0[137]|6[27])|6(?:01|74|[68][68])|7(?:11|3[029])))',
+    '132' => '(?:8(?:5(?:[18]5|5[015]|3[03]|0[137]|6[27])|6(?:01|74|[68][68])|7(?:11|3[029])))',
     '133' => '(?:8(?:5(?:[01]1|8[058]|5[238])|70[46]))',
     '134' => '(?:8(?:5(?:[15]5|20|33|7[05-7]|8[5-8]|0[237])|6(?:22|86|[14][02]|0[1-39]|3[01])|702))',
     '135' => '(?:8(?:5(?:48|3[0-358]|7[57-9]|2[1-3578]|8[1257]|1[0-478]|5[0-24-9]|0[12458]|6[035-8])|4(?:4[0358]|2[27]|0[24]|5[18]|8[0-2]|7[037]|6[014]|1[15]|3[026])|6(?:86|0[28]|2[0-25]|6[168]|3[0-29]|7[078]|1[014-9]|5[059])|3(?:[25]0|8[3-57]|0[1368]|7[05]|6[023]|3[01]|1[0-28])|1(?:21|50|65|78|1[01458]|0[89]|3[0479]|8[01])|7(?:97|3[0-3]|2[0-37]|0[17]|1[0178])|2(?:10|2[24])|0(?:74|80)))',
@@ -149,7 +149,7 @@ our %ZIP_TABLE = (
     '156' => '(?:8(?:5(?:33|55|88|0[246]|2[02]|1[01])|666))',
     '157' => '(?:85(?:43|50|6[1-35-7]|3[05]|0[18]|2[0-2]|7[0357]|1[01]))',
     '158' => '(?:8(?:5(?:3[1349]|5[0-278]|8[0568]|1[0-48]|6[167]|4[349]|2[0235]|7[578]|0[1-3589])|6(?:40|66|3[0-3]|2[28]|1[05]|0[12])|7[07]1))',
-    '160' => '(?:8(?:3(?:89|7[3-58]|3[01468]|1[1369]|[24][17]|6[168]|5[1-38]|0[1469])|4(?:50|72|1[015]|3[03]|2[0239]|6[136]|4[147]|8[4-9]|0[1-37-9])|5(?:65|1[0-2569]|0[1479]|4[37]|8[0-37-9]|2[0-249]|3[05]|7[157])|0(?:[01]1|70)|6(?:01|80)|8(?:01|12)|910))',
+    '160' => '(?:8(?:3(?:89|7[3-58]|3[01468]|1[1369]|[24][17]|5[1-38]|6[68]|0[1469])|4(?:50|72|1[015]|3[03]|2[0239]|6[136]|4[147]|8[4-9]|0[1-37-9])|5(?:65|1[0-2569]|0[1479]|4[37]|8[0-37-9]|2[0-249]|3[05]|7[157])|0(?:[01]1|70)|6(?:01|80)|8(?:01|12)|910))',
     '161' => '(?:8(?:5(?:08|11|75|3[19]|6[057]|5[236-8]|4[0156]|2[0-28])|710))',
     '162' => '(?:8(?:6(?:[78]0|1[24-6]|2[0468]|5[04-6]|[36][689]|4[046]|0[1248])|4(?:33|5[015]|6[04]|4[058]|7[1368]|8[048]|0[27]|2[12]|1[125])|5(?:75|[16][25]|0[235]|3[05]|8[57]|5[16-8]|4[034])|8(?:30|5[03]|0[1-8]|6[01])|0(?:55|60|2[0-2]|0[15])|7(?:0[17]|1[016-8])|953))',
     '163' => '(?:(?:0(?:5(?:5[378]|7[056]|6[0269])|6(?:7[5-7]|5[59]|6[359])|8(?:50|67|3[136])|2(?:78|6[18])|4(?:56|7[18])|9(?:43|3[68])|7[27]7)|1(?:3(?:50|63|71|4[59]|8[28])|0(?:7[13]|6[156]|5[35])|4(?:55|70|88)|5(?:88|3[37]))|8(?:6(?:[28]0|02|3[89]|7[17]|6[016])|0(?:0[13]|8[0-2]|1[29])|5(?:35|48))))',
@@ -304,7 +304,7 @@ our %ZIP_TABLE = (
     '328' => '(?:(?:8(?:5(?:33|0[1-4]|5[0568]|8[5-8])|6(?:86|6[68]))|0192))',
     '329' => '(?:(?:0(?:49[238]|59[568]|69[26]|195)|1(?:19[3468]|39[235]|292|493)|2(?:79[23]|99[23]|[12]92)|4(?:49[238]|392)|3292))',
     '330' => '(?:(?:9(?:5(?:90|5[013589]|4[03-58]|8[0-36-8]|6[4-6]|3[156]|2[05]|7[57]|1[12]|0[1-37-9])|7(?:9[1-367]|3[19]|2[07]|1[0357])|6(?:[69]6|11|30|88|0[18]|2[126])|3(?:30|77|0[13]|1[01])|1(?:09|1[01])|0(?:11|45)|850)|8(?:5(?:6[24-6]|4[78]|5[0-37]|0[13568]|3[238]|1[0189]|2[29]|7[129]|8[0159])|6(?:34|47|69|71|0[13]|8[68])|7(?:08|10|77))))',
-    '331' => '(?:(?:8(?:5(?:[24]0|01|77|1[13]|8[05-8]|5[02]|6[07]|3[237])|6(?:25|33|58|8[6-8])|701)|95(?:[1-35]0|77)))',
+    '331' => '(?:(?:8(?:5(?:[24]0|01|77|1[13]|5[02]|6[07]|3[237]|8[06-8])|6(?:25|33|58|8[6-8])|701)|95(?:[1-35]0|77)))',
     '332' => '(?:8(?:5(?:21|48|77|85|0[1-3]|5[568]|1[12])|6(?:[68]6|01|54)))',
     '333' => '(?:86[01]1)',
     '334' => '(?:8501)',
@@ -426,7 +426,7 @@ our %ZIP_TABLE = (
     '452' => '(?:8(?:5(?:70|0[1-3]|6[1-79])|60[12]))',
     '453' => '(?:8(?:5(?:40|8[015]|3[39]|7[07]|5[58]|6[57]|2[12]|0[15]|1[0-28])|6(?:[28]6|11|62|0[18])|7(?:58|65|77|0[14])))',
     '454' => '(?:8(?:5(?:3[03]|2[0-24-79]|5[058]|1[125-9]|6[05]|0[1-689])|651))',
-    '455' => '(?:8(?:5(?:[458]5|60|1[25]|[02][15]|3[035])|6(?:[46]8|10|2[06]|3[09]|0[156]|7[01])|777))',
+    '455' => '(?:8(?:5(?:[458]5|60|77|1[25]|[02][15]|3[035])|6(?:[46]8|10|2[06]|3[09]|0[156]|7[01])|777))',
     '456' => '(?:8(?:5(?:23|30|44|0[1-3]|6[07]|1[16]|8[0578]|5[56])|6(?:20|91|0[12]|1[0-2]|[68][68])|7(?:11|39|63)))',
     '457' => '(?:8(?:5(?:22|45|77|3[0-35]|5[158]|1[0-25]|6[067]|8[58]|0[18])|71[12]))',
     '458' => '(?:85(?:30|55|8[015]|0[1258]|1[05]|2[0-2]|7[01]))',
@@ -693,7 +693,7 @@ our %ZIP_TABLE = (
     '731' => '(?:(?:0(?:19[2-8]|29[235]|59[235]|692)|3(?:19[2-68]|39[358]|595)|4(?:39[236-8]|29[23])|1(?:59[57]|795)|519[35-8]|219[58]))',
     '732' => '(?:8(?:5(?:55|80|6[4-6]|7[05]|1[0-2]|0[13-57-9])|652|765))',
     '733' => '(?:8(?:6(?:89|3[03]|4[1-36-8]|6[09]|7[0578]|0[18]|2[1-7]|5[01]|1[016])|5(?:0[19]|4[0358]|5[0-358]|2[0158]|3[0135]|1[0-4])|701))',
-    '734' => '(?:8(?:5(?:[37]0|22|43|58|6[07]|1[035])|798))',
+    '734' => '(?:8(?:5(?:[37]0|22|43|58|85|6[07]|1[035])|798))',
     '735' => '(?:8(?:5(?:01|55|77|88|1[01])|6(?:70|86)))',
     '736' => '(?:8(?:5(?:10|55|0[124-9])|60[12]))',
     '737' => '(?:(?:8(?:5(?:20|41|54|0[1-9]|1[236-8])|6(?:09|11|86|5[0-3]))|2(?:29[357]|19[35]|39[37])|01(?:82|9[2358])))',
